@@ -28,3 +28,20 @@ from CIM14.IEC61968.Customers.ServiceLocation import ServiceLocation
 from CIM14.IEC61968.Customers.CustomerAgreement import CustomerAgreement
 from CIM14.IEC61968.Customers.Tariff import Tariff
 
+class RevenueKind(str):
+    """Accounting classification of the type of revenue collected for the CustomerAgreement, typically used to break down accounts for revenue accounting.
+    Values are: industrial, streetLight, other, nonResidential, irrigation, residential, commercial
+    """
+    pass
+
+class CustomerKind(str):
+    """Kind of customer.
+    Values are: residentialAndCommercial, residentialStreetlightOthers, residentialAndStreetlight, pumpingLoad, energyServiceSupplier, windMachine, residential, internalUse, residentialFarmService, other, energyServiceScheduler, commercialIndustrial
+    """
+    pass
+
+class ServiceKind(str):
+    """Kind of service.
+    Values are: water, time, electricity, heat, rates, gas, internet, refuse, other, tvLicence, sewerage
+    """
+    pass
